from django.contrib import admin
from clvoucherApp.models import *
# Register your models here.


class VoucherAdmin(admin.ModelAdmin):
    list_display = [
        'voucher_code',
        'name',
        'branch',
        'discount_value_sessions',
        'discount_value_visits',
        'max_sessions',
        'max_visits',
        'validity_days',
        'is_active',
        'created_at',
        'created_by'
    ]
    
    # list_editable = ['is_active']
    list_filter = [
        'branch',
        'is_active',
        'created_at'
    ]
    search_fields = [
        'voucher_code',
        'name',
        'branch__name'
    ]
    readonly_fields = [
        'created_at',
        'updated_at',
        'voucher_code'
    ]
    fieldsets = (
        ('Basic Information', {
            'fields': (
                'branch',
                'voucher_code',
                'name',
                'description',
                'is_active'
            )
        }),
        ('Discount Settings', {
            'fields': (
                'discount_value_sessions',
                'discount_value_visits',
                'max_sessions',
                'max_visits',
                'validity_days'
            )
        }),
        ('Metadata', {
            'fields': (
                'created_by',
                'created_at',
                'updated_at'
            ),
            'classes': ('collapse',)
        })
    )
    
    # def save_model(self, request, obj, form, change):
    #     if not obj.pk and not obj.voucher_code:
    #         # Generate voucher code if not provided
    #         obj.voucher_code = generate_voucher_code()  # You need to implement this
    #     obj.created_by = request.user
    #     super().save_model(request, obj, form, change)

admin.site.register(Voucher, VoucherAdmin)

class PatientVoucherAdmin(admin.ModelAdmin):
    list_display = [
        'voucher_code_assigned',
        'patient',
        'voucher',
        'discount_amount_sessions_assigned',
        'discount_amount_visits_assigned',
        'expires_at',
        'is_used_session',
        'visits_uses_count',
        'is_wa_sent',
        'msg_status',
        'created_at'
    ]
    
    # list_editable = ['msg_status']
    list_filter = [
        'voucher',
        'is_used_session',
        'is_wa_sent',
        'msg_status',
        'expires_at',
        'campaign'
    ]
    search_fields = [
        'voucher_code_assigned',
        'patient__fullname',
        'patient__number_1',
        'voucher__name'
    ]
    readonly_fields = [
        'created_at',
        'created_by',
        'voucher_code_assigned'
    ]
    raw_id_fields = ['patient', 'voucher', 'pt_session']
    date_hierarchy = 'created_at'
    
    fieldsets = (
        ('Voucher Details', {
            'fields': (
                'voucher',
                'patient',
                'voucher_code_assigned'
            )
        }),
        ('Discount Information', {
            'fields': (
                'discount_amount_sessions_assigned',
                'discount_amount_visits_assigned',
                'max_sessions',
                'max_visits',
                'expires_at'
            )
        }),
        ('Usage Tracking', {
            'fields': (
                'is_used_session',
                'pt_session',
                'visits_uses_count'
            )
        }),
        ('Messaging Status', {
            'fields': (
                'is_wa_sent',
                'msg_status',
                'campaign',
                'try_send_at'
            )
        }),
        ('Metadata', {
            'fields': (
                'issuer_notes',
                'created_by',
                'created_at'
            ),
            'classes': ('collapse',)
        })
    )
    
    # def save_model(self, request, obj, form, change):
    #     if not obj.pk:
    #         obj.created_by = request.user
    #         if not obj.voucher_code_assigned:
    #             obj.voucher_code_assigned = generate_patient_voucher_code(obj)
    #     super().save_model(request, obj, form, change)

admin.site.register(PatientVoucher, PatientVoucherAdmin)

from django.contrib import admin
from .models import Campaign

class CampaignAdmin(admin.ModelAdmin):
    # Show all fields in list view
    list_display = [
        'name', 
        'msg_prefix', 
        'voucher', 
        'created_by',
        'created_at',
        'updated_at',
        'filter_start_date',
        'filter_end_date',
        'filter_pt_status',
        'status',
        'total_recipients',
        'success_count',
        'failed_count'
    ]
    
    # Make status editable directly in list view
    list_editable = ['status']
    
    # Add filters for better navigation
    list_filter = [
        'status',
        'created_at',
        'voucher',
        'created_by'
    ]
    
    # Add search functionality
    search_fields = [
        'name',
        'msg_prefix',
        'voucher__name'
    ]
    
    # Fields to display in edit form
    fieldsets = (
        (None, {
            'fields': (
                'name',
                'msg_prefix',
                'voucher',
                'status',
                'created_by'
            )
        }),
        ('Filters', {
            'fields': (
                'filter_start_date',
                'filter_end_date',
                'filter_pt_status'
            ),
            'classes': ('collapse',)  # Makes this section collapsible
        }),
        ('Statistics', {
            'fields': (
                'total_recipients',
                'success_count',
                'failed_count'
            )
        })
    )
    
    # Read-only fields (can't be edited)
    readonly_fields = [
        'created_at',
        'updated_at',
        'total_recipients',
        'success_count',
        'failed_count'
    ]
    
    # Automatically set the created_by field to current user
    def save_model(self, request, obj, form, change):
        if not obj.pk:  # Only on create
            obj.created_by = request.user
        super().save_model(request, obj, form, change)

admin.site.register(Campaign, CampaignAdmin)

#admin.site.register(Voucher)